const { app, BrowserWindow, Menu, session, globalShortcut } = require('electron');
const createMenuOptions = require('./appMenu.js').default;
const packageJson = require('../../package.json');
const contextMenu = require('electron-context-menu');
// global reference to mainWindow (necessary to prevent window from being garbage collected)
let mainWindow;

function createMainWindow() {
	const window = new BrowserWindow({
		width: 1800,
		height: 1000,
		minWidth: 800,
		minHeight: 600,
		center: true
	});

	window.loadURL(packageJson.brandPlatformUrl);
	const menuOptions = createMenuOptions(app, session);
	const appMenu = Menu.buildFromTemplate(menuOptions);
	Menu.setApplicationMenu(appMenu);

	window.on('closed', () => {
		mainWindow = null;
	});

	window.webContents.on('devtools-opened', () => {
		window.focus();
		setImmediate(() => {
			window.focus();
		});
	});

	return window;
}

app.allowRendererProcessReuse = true;

// quit application when all windows are closed
app.on('window-all-closed', () => {
	// on macOS it is common for applications to stay open until the user explicitly quits
	if (process.platform !== 'darwin') {
		app.quit();
	}
});

app.on('activate', () => {
	// on macOS it is common to re-create a window even after all windows have been closed
	if (mainWindow === null) {
		mainWindow = createMainWindow();
	}
});

// create main BrowserWindow when electron is ready
app.on('ready', () => {
	mainWindow = createMainWindow();
});

app.on('web-contents-created', (e, contents) => {
	contextMenu({
		window: contents,
		showSaveImageAs: true,
		showInspectElement: false
	});
});
